unbound-adblock 0.5 errata 005, March 25, 2021:

This is an errata release to address an issue regarding RPZ semantics.

Issues fixed:

* Unbound does not properly enforce the "rpz-passthru." option's precedence requirements, so accommodate this fact.

* RPZ whitelisting rules were not exported with the '-x' option.

* RPZ whitelisting rules were not accounted for in statistics reports.

* While here, nuke some unused variables.

Apply by doing: (Note: Provided file path is for OpenBSD, other platforms path may differ)

# patch /usr/local/bin/unbound-adblock < p4.patch

NOTE: This patch is dependent upon all previously released patches.
You can use this 1 liner to check your currently installed version:
...
$ unbound-adblock -h 2>/dev/null | awk 'FNR==3 {print $3}'
$ 0.5p4
...

'0.5p0' means you have the first patch installed, if there is no "p*" suffix, then that means you have no patches installed.


--- unbound-adblock.sh.orig4	Thu Jan 28 14:09:29 2021
+++ unbound-adblock.sh	Wed Mar 24 15:21:32 2021
@@ -23,7 +23,7 @@
 # Fetch, parse and generate domain blocklists data into format suitable 
 # for ingestion by RPZ compatible DNS servers and/or unbound/unwind.
 
-version='0.5p3'
+version='0.5p4'
 release_date='2021-01-10'
 release_name='Gaslight Republic'
 
@@ -270,8 +270,6 @@
 }
 
 LIST_GEN() {
-	typeset _i
-
 	# Delete empty files
 	find "${tmpdir_domain}" "${tmpdir_hosts}" -type f -size 0 -delete || WARN_ERR 'ERROR: Failed to delete temporary files!'
 
@@ -312,8 +310,9 @@
 		{ printf '# Date Created: %s\n' "$(date)" && PRINT_STATS | sed 's/^/# /g' && printf '\n' && cat -- < "${cnvtemp}" ;} > "${finout}" || TMP_FILE_ABORT
 	# Cross-platform RPZ data
 	else
-		{ printf ';; Date Created: %s\n' "$(date)" && PRINT_STATS | sed 's/^/;; /g' ; printf '\n' && cat -- < "${cnvtemp}" \
-		  && if test -s "${user_rules}" ; then printf '\n;; Whitelist:\n\n' && cat -- < "${user_rules}" ; fi ;} > "${finout}" || TMP_FILE_ABORT
+		{ printf ';; Date Created: %s\n' "$(date)" && PRINT_STATS | sed 's/^/;; /g' \
+		  && if test -s "${user_rules}" ; then printf '\n;; Whitelist:\n\n' && cat -- < "${user_rules}" ; fi \
+		  && printf '\n;; Blocklist:\n\n' && cat -- < "${cnvtemp}" ;} > "${finout}" || TMP_FILE_ABORT
 	fi
 
 	# Calculate byte offsets (to ignore info headers in cmp)
@@ -384,9 +383,12 @@
 
 PRINT_STATS() {
 	# Calculate blocklist entries in current and previously installed lists
-	typeset -i new_num old_num
-	new_num="$(SANITIZE_ARRAY_NO_SORT < "${rawout}" | wc -l)"
+	typeset -i blk_num new_num old_num usr_num
+
+	blk_num="$(SANITIZE_ARRAY_NO_SORT < "${rawout}" | wc -l)"
 	old_num="$(SANITIZE_ARRAY_NO_SORT < "${oldconf}" | wc -l)"
+	usr_num="${#_user_rule[@]}"
+	new_num="$((usr_num + blk_num))"
 
 	# Need to preface with '+', so do not store as integer
 	typeset changes="$((new_num - old_num))"
@@ -526,8 +528,6 @@
 
 # Make sure user-provided values are sane
 VAR_SANITY_CHECK() {
-	typeset _cmd
-
 	IS_INT "${_ALT_RPZ}" || ERR 'User defined variable "$_ALT_RPZ" contains a non-integer value - Unable to proceed!'
 	IS_INT "${_ALT_UNBOUND}" || ERR 'User defined variable "$_ALT_UNBOUND" contains a non-integer value - Unable to proceed!'
 	IS_INT "${_ALT_UNWIND}" || ERR 'User defined variable "$_ALT_UNWIND" contains a non-integer value - Unable to proceed!'
@@ -939,6 +939,9 @@
 	if [ "${_PRINT_ONLY}" -eq 1 ]; then
 		if [ "${_ALT_RPZ}" -eq 1 ]; then
 			# Print cross-platform RPZ blocklist data to stdout
+			if test -s "${user_rules}" ; then 
+				cat -- < "${user_rules}"
+			fi
 			sed 's/$/ CNAME ./g' < "${rawout}"
 		elif [ "${_ALT_UNWIND}" -eq 1 ]; then
 			# Print raw domain blocklist data to stdout
